espei.error\_functions package
==============================

Submodules
----------

espei.error\_functions.activity\_error module
---------------------------------------------

.. automodule:: espei.error_functions.activity_error
   :members:
   :undoc-members:
   :show-inheritance:

espei.error\_functions.context module
-------------------------------------

.. automodule:: espei.error_functions.context
   :members:
   :undoc-members:
   :show-inheritance:

espei.error\_functions.equilibrium\_thermochemical\_error module
----------------------------------------------------------------

.. automodule:: espei.error_functions.equilibrium_thermochemical_error
   :members:
   :undoc-members:
   :show-inheritance:

espei.error\_functions.non\_equilibrium\_thermochemical\_error module
---------------------------------------------------------------------

.. automodule:: espei.error_functions.non_equilibrium_thermochemical_error
   :members:
   :undoc-members:
   :show-inheritance:

espei.error\_functions.residual\_base module
--------------------------------------------

.. automodule:: espei.error_functions.residual_base
   :members:
   :undoc-members:
   :show-inheritance:

espei.error\_functions.zpf\_error module
----------------------------------------

.. automodule:: espei.error_functions.zpf_error
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: espei.error_functions
   :members:
   :undoc-members:
   :show-inheritance:
